@@ -8,15 +8,12 @@ if sys.version_info < (2, 7):
 else:
     import unittest  # noqa
 
-from mopidy import settings
-
-# Nuke any local settings to ensure same test env all over
-settings.local.clear()
-
 
 def path_to_data_dir(name):
+    if not isinstance(name, bytes):
+        name = name.encode(sys.getfilesystemencoding())
     path = os.path.dirname(__file__)
-    path = os.path.join(path, 'data')
+    path = os.path.join(path, b'data')
     path = os.path.abspath(path)
     return os.path.join(path, name)
 
