@@ -1,21 +1,21 @@
+from __future__ import unicode_literals
+
 import json
 
 try:
     import cherrypy
 except ImportError:
     cherrypy = False
+
 try:
     import ws4py
 except ImportError:
     ws4py = False
+
+if cherrypy and ws4py:
+    from mopidy.frontends.http import actor
+
 import mock
-
-from mopidy.exceptions import OptionalDependencyError
-try:
-    from mopidy.frontends.http import HttpFrontend
-except OptionalDependencyError:
-    pass
-
 from tests import unittest
 
 
@@ -24,7 +24,14 @@ from tests import unittest
 @mock.patch('cherrypy.engine.publish')
 class HttpEventsTest(unittest.TestCase):
     def setUp(self):
-        self.http = HttpFrontend(core=mock.Mock())
+        config = {
+            'http': {
+                'hostname': '127.0.0.1',
+                'port': 6680,
+                'static_dir': None,
+            }
+        }
+        self.http = actor.HttpFrontend(config=config, core=mock.Mock())
 
     def test_track_playback_paused_is_broadcasted(self, publish):
         publish.reset_mock()
