@@ -15,15 +15,19 @@ class LocaleDecodeTest(unittest.TestCase):
         result = locale_decode(
             b'[Errno 98] Adresse d\xc3\xa9j\xc3\xa0 utilis\xc3\xa9e')
 
-        self.assertEquals('[Errno 98] Adresse d\xe9j\xe0 utilis\xe9e', result)
+        self.assertEqual('[Errno 98] Adresse d\xe9j\xe0 utilis\xe9e', result)
 
     def test_can_decode_an_ioerror_with_french_content(self, mock):
         mock.return_value = 'UTF-8'
 
         error = IOError(98, b'Adresse d\xc3\xa9j\xc3\xa0 utilis\xc3\xa9e')
         result = locale_decode(error)
+        expected = '[Errno 98] Adresse d\xe9j\xe0 utilis\xe9e'
 
-        self.assertEquals('[Errno 98] Adresse d\xe9j\xe0 utilis\xe9e', result)
+        self.assertEqual(
+            expected, result,
+            '%r decoded to %r does not match expected %r' % (
+                error, result, expected))
 
     def test_does_not_use_locale_to_decode_unicode_strings(self, mock):
         mock.return_value = 'UTF-8'
